# eric7.CycloneDXInterface.CycloneDXMetaDataDialog

Module implementing a dialog to edit the metadata of the CycloneDX SBOM.

### Global Attributes

None

### Classes

CycloneDXMetaDataDialog | Class implementing a dialog to edit the metadata of the CycloneDX SBOM.

### Functions

None

## CycloneDXMetaDataDialog

Class implementing a dialog to edit the metadata of the CycloneDX SBOM.

### Derived from

QDialog, Ui_CycloneDXMetaDataDialog

### Class Attributes

ComponentTypeMapping

### Class Methods

None

### Methods

CycloneDXMetaDataDialog | Constructor
__populateComponentTypeSelector | Private method to populate the component type selector.
__populateLicenseSelector | Private method to populate the license selector with the list of trove license types.
__updateOkButton | Private slot to update the enabled state of the OK button.
getMetaData | Public method to get the entered data.

### Static Methods

None

#### CycloneDXMetaDataDialog (Constructor)

CycloneDXMetaDataDialog(metadata=None, parent=None)

Constructor

metadata (dict (optional))
  dictionary containing metadata to populate the dialog (defaults to None)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### CycloneDXMetaDataDialog.__populateComponentTypeSelector

__populateComponentTypeSelector()

Private method to populate the component type selector.

#### CycloneDXMetaDataDialog.__populateLicenseSelector

__populateLicenseSelector()

Private method to populate the license selector with the list of trove license types.

#### CycloneDXMetaDataDialog.__updateOkButton

__updateOkButton()

Private slot to update the enabled state of the OK button.

#### CycloneDXMetaDataDialog.getMetaData

getMetaData()

Public method to get the entered data.

Return:
  dictionary containing the metadata.

Return Type:
  dict

Up